module.exports =
  /**
   * @type {const}
   * @satisfies {import("@clockworkdog/cogs-client").CogsPluginManifest}
   */
  ({
    name: 'Custom Content Example',
    icon: 'vial',
    description:
      'An example of custom media master content that acts as a testbed with one of each type of config, state, and event',
    version: '1',
    config: [
      {
        name: 'Boolean Config',
        value: { type: 'boolean', default: false },
      },
      {
        name: 'Number Config',
        value: { type: 'number', default: 0 },
      },
      {
        name: 'String Config',
        value: { type: 'string', default: '' },
      },
      {
        name: 'Option Config',
        value: {
          type: 'option',
          options: ['Option 1', 'Option 2', 'Option 3'],
          default: 'Option 1',
        },
      },
    ],
    state: [
      {
        name: 'Boolean From COGS',
        value: { type: 'boolean', default: false },
        writableFromCogs: true,
      },
      {
        name: 'Number From COGS',
        value: { type: 'number', default: 0 },
        writableFromCogs: true,
      },
      {
        name: 'String From COGS',
        value: { type: 'string', default: '' },
        writableFromCogs: true,
      },
      {
        name: 'Option From COGS',
        value: {
          type: 'option',
          options: ['Option 1', 'Option 2', 'Option 3'],
          default: 'Option 1',
        },
        writableFromCogs: true,
      },
      {
        name: 'Boolean From Client',
        value: { type: 'boolean', default: false },
        writableFromClient: true,
      },
      {
        name: 'Number From Client',
        value: { type: 'number', default: 0 },
        writableFromClient: true,
      },
      {
        name: 'String From Client',
        value: { type: 'string', default: '' },
        writableFromClient: true,
      },
      {
        name: 'Option From Client',
        value: {
          type: 'option',
          options: ['Option 1', 'Option 2', 'Option 3'],
          default: 'Option 1',
        },
        writableFromClient: true,
      },
    ],
    events: {
      toCogs: [
        {
          name: 'No Value Event From Client',
        },
        {
          name: 'Boolean Event From Client',
          value: { type: 'boolean' },
        },
        {
          name: 'Number Event From Client',
          value: { type: 'number' },
        },
        {
          name: 'String Event From Client',
          value: { type: 'string' },
        },
        {
          name: 'Option Event From Client',
          value: {
            type: 'option',
            options: ['Option 1', 'Option 2', 'Option 3'],
          },
        },
      ],
      fromCogs: [
        {
          name: 'No Value Event From COGS',
        },
        {
          name: 'Boolean Event From COGS',
          value: { type: 'boolean' },
        },
        {
          name: 'Number Event From COGS',
          value: { type: 'number' },
        },
        {
          name: 'String Event From COGS',
          value: { type: 'string' },
        },
        {
          name: 'Option Event From COGS',
          value: {
            type: 'option',
            options: ['Option 1', 'Option 2', 'Option 3'],
          },
        },
      ],
    },
    media: {
      audio: true,
      video: true,
    },
  });
