const { CogsConnection, CogsAudioPlayer, CogsVideoPlayer } = COGS;

const cogsConnection = new CogsConnection();

const audioPlayer = new CogsAudioPlayer(cogsConnection);
const videoPlayer = new CogsVideoPlayer(cogsConnection);

let connected = false;

// Config
let configBoolean = false;
let configNumber = 0;
let configString = '';
let configOption = 'Option 1';

// State (from COGS -> Client)
let stateFromCogsBoolean = false;
let stateFromCogsNumber = 0;
let stateFromCogsString = '';
let stateFromCogsOption = 'Option 1';

// State (from Client -> COGS)
let stateFromClientBoolean = false;
let stateFromClientNumber = 0;
let stateFromClientString = '';
let stateFromClientOption = 'Option 1';

function syncUi() {
  // Connection status
  document.getElementById('connected-indicator').innerHTML = connected
    ? 'Connected'
    : 'Disconnected';
  document.getElementById('connected-indicator').classList.toggle('connected', connected);

  // Config
  document.getElementById('config-boolean').innerHTML = String(configBoolean);
  document.getElementById('config-number').innerHTML = String(configNumber);
  document.getElementById('config-string').innerHTML = String(configString);
  document.getElementById('config-option').innerHTML = String(configOption);

  // State
  document.getElementById('state-from-cogs-boolean').innerHTML = String(stateFromCogsBoolean);
  document.getElementById('state-from-cogs-number').innerHTML = String(stateFromCogsNumber);
  document.getElementById('state-from-cogs-string').innerHTML = String(stateFromCogsString);
  document.getElementById('state-from-cogs-option').innerHTML = String(stateFromCogsOption);
}

function syncStateToCogs() {
  cogsConnection.setState({
    'Boolean From Client': stateFromClientBoolean,
    'Number From Client': stateFromClientNumber,
    'String From Client': stateFromClientString,
    'Option From Client': stateFromClientOption,
  });
}

// State from client listeners
document.getElementById('state-from-client-boolean').addEventListener('change', (e) => {
  stateFromClientBoolean = e.target.checked;
  syncStateToCogs();
});
document.getElementById('state-from-client-number').addEventListener('change', (e) => {
  stateFromClientNumber = e.target.valueAsNumber;
  syncStateToCogs();
});
document.getElementById('state-from-client-string').addEventListener('change', (e) => {
  stateFromClientString = e.target.value;
  syncStateToCogs();
});
document.getElementById('state-from-client-option').addEventListener('change', (e) => {
  stateFromClientOption = e.target.value;
  syncStateToCogs();
});

// Send event listeners
document.getElementById('event-from-client-no-value-send').addEventListener('click', () => {
  cogsConnection.sendEvent('No Value Event From Client');
});
document.getElementById('event-from-client-boolean-send').addEventListener('click', () => {
  const value = document.getElementById('event-from-client-boolean-value').checked;
  cogsConnection.sendEvent('Boolean Event From Client', value);
});
document.getElementById('event-from-client-number-send').addEventListener('click', () => {
  const value = document.getElementById('event-from-client-number-value').valueAsNumber;
  cogsConnection.sendEvent('Number Event From Client', value);
});
document.getElementById('event-from-client-string-send').addEventListener('click', () => {
  const value = document.getElementById('event-from-client-string-value').value;
  cogsConnection.sendEvent('String Event From Client', value);
});
document.getElementById('event-from-client-option-send').addEventListener('click', () => {
  const value = document.getElementById('event-from-client-option-value').value;
  cogsConnection.sendEvent('Option Event From Client', value);
});

cogsConnection.addEventListener('open', () => {
  connected = true;

  syncUi();
  syncStateToCogs();
});
cogsConnection.addEventListener('close', () => {
  connected = false;

  syncUi();
});
cogsConnection.addEventListener('config', ({ config }) => {
  // Handle new config
  // `config` is of type `{ [name: string]: number | string | boolean }`
  console.log('Config update', config);

  configBoolean = config['Boolean Config'] ?? configBoolean;
  configNumber = config['Number Config'] ?? configNumber;
  configString = config['String Config'] ?? configString;
  configOption = config['Option Config'] ?? configOption;

  syncUi();
});
cogsConnection.addEventListener('state', ({ state }) => {
  // Handle state updates
  // `state` is of type `{ [name: string]: number | string | boolean }`

  console.log('State update', state);

  stateFromCogsBoolean = state['Boolean From COGS'] ?? stateFromCogsBoolean;
  stateFromCogsNumber = state['Number From COGS'] ?? stateFromCogsNumber;
  stateFromCogsString = state['String From COGS'] ?? stateFromCogsString;
  stateFromCogsOption = state['Option From COGS'] ?? stateFromCogsOption;

  syncUi();
});
cogsConnection.addEventListener('event', ({ name, value }) => {
  // Handle events from COGS
  // `name` is the event name.
  // `value` is of the type defined in manifest, one of `number | string | boolean | undefined`.

  console.log('Event from COGS:', { name, value });

  function flash(readoutId, valueId) {
    document.getElementById(readoutId).classList.add('flash');
    if (valueId) {
      document.getElementById(valueId).innerHTML = String(value);
    }
    setTimeout(() => {
      document.getElementById(readoutId).classList.remove('flash');

      if (valueId) {
        document.getElementById(valueId).innerHTML = '';
      }
    }, 500);
  }

  if (name === 'No Value Event From COGS') {
    flash('event-from-cogs-no-value');
  } else if (name === 'Boolean Event From COGS') {
    flash('event-from-cogs-boolean', 'event-from-cogs-boolean-value');
  } else if (name === 'Number Event From COGS') {
    flash('event-from-cogs-number', 'event-from-cogs-number-value');
  } else if (name === 'String Event From COGS') {
    flash('event-from-cogs-string', 'event-from-cogs-string-value');
  } else if (name === 'Option Event From COGS') {
    flash('event-from-cogs-option', 'event-from-cogs-option-value');
  }
});
cogsConnection.addEventListener('message', ({ message }) => {
  // Handle low-level COGS messages. See `types/CogsClientMessage.ts`
});
